@@ -1,6 +1,6 @@
 
 from sqlalchemy import inspect, orm, and_, or_
-from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
+from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm.exc import UnmappedClassError
 
 import query
@@ -217,21 +217,25 @@ class QueryProperty(object):
         try:
             mapper = orm.class_mapper(Model)
             if mapper:
+                if not getattr(Model, 'query_class', None):
+                    Model.query_class = query.Query
+
                 q = Model.query_class(mapper, session=self.session())
                 q.__model__ = Model
+
                 return q
         except UnmappedClassError:
             return None
 
-def make_declarative_base(session=None, query_property=None):
-    Base = declarative_base(cls=ModelBase, constructor=ModelBase.__init__)
-    extend_declarative_base(Base, session, query_property)
-    return Base
+def make_declarative_base(session=None, query_property=None, Model=None):
+    Model = Model or declarative_base(cls=ModelBase, constructor=ModelBase.__init__)
+    extend_declarative_base(Model, session, query_property)
+    return Model
 
-def extend_declarative_base(Base, session=None, query_property=None):
-    # attach query attribute to Base if `session` object passed in
+def extend_declarative_base(Model, session=None, query_property=None):
+    # attach query attribute to Model if `session` object passed in
     if session:
-        Base.query = query_property(session) if query_property else QueryProperty(session)
+        Model.query = query_property(session) if query_property else QueryProperty(session)
 
-    return Base
+    return Model
 
